@@ -3,7 +3,6 @@
 // Copyright (c) Contributors to the OpenEXR Project.
 //
 
-
 //-----------------------------------------------------------------------------
 //
 //	class StringAttribute
@@ -14,11 +13,10 @@
 
 #include "ImfStringAttribute.h"
 
-
 #if defined(_MSC_VER)
 // suppress warning about non-exported base classes
-#pragma warning (disable : 4251)
-#pragma warning (disable : 4275)
+#    pragma warning(disable : 4251)
+#    pragma warning(disable : 4275)
 #endif
 
 OPENEXR_IMF_INTERNAL_NAMESPACE_SOURCE_ENTER
@@ -34,35 +32,34 @@ using namespace OPENEXR_IMF_INTERNAL_NAMESPACE;
 //#endif
 
 template <>
-IMF_EXPORT const char *
+IMF_EXPORT const char*
 TypedAttribute<std::string>::staticTypeName ()
 {
     return "string";
 }
 
-
 template <>
 IMF_EXPORT void
-TypedAttribute<std::string>::writeValueTo (OPENEXR_IMF_INTERNAL_NAMESPACE::OStream &os, int version) const
+TypedAttribute<std::string>::writeValueTo (
+    OPENEXR_IMF_INTERNAL_NAMESPACE::OStream& os, int version) const
 {
-    int size = _value.size();
+    int size = _value.size ();
 
     for (int i = 0; i < size; i++)
-	Xdr::write <StreamIO> (os, _value[i]);
+        Xdr::write<StreamIO> (os, _value[i]);
 }
 
-
 template <>
 IMF_EXPORT void
-TypedAttribute<std::string>::readValueFrom (OPENEXR_IMF_INTERNAL_NAMESPACE::IStream &is, int size, int version)
+TypedAttribute<std::string>::readValueFrom (
+    OPENEXR_IMF_INTERNAL_NAMESPACE::IStream& is, int size, int version)
 {
     _value.resize (size);
 
     for (int i = 0; i < size; i++)
-	Xdr::read <StreamIO> (is, _value[i]);
+        Xdr::read<StreamIO> (is, _value[i]);
 }
 
 template class IMF_EXPORT_TEMPLATE_INSTANCE TypedAttribute<std::string>;
 
-
-OPENEXR_IMF_INTERNAL_NAMESPACE_SOURCE_EXIT 
+OPENEXR_IMF_INTERNAL_NAMESPACE_SOURCE_EXIT
