@@ -99,9 +99,10 @@ generateRandomFile (
 
     frameBuffer.insertSampleCountSlice (Slice (
         IMF::UINT, // type // 7
-        (char*) (&sampleCount[0][0] - dataWindow.min.x - dataWindow.min.y * width), // base // 8
-        sizeof (unsigned int) * 1,       // xStride// 9
-        sizeof (unsigned int) * width)); // yStride// 10
+        (char*) (&sampleCount[0][0] - dataWindow.min.x -
+                 dataWindow.min.y * width), // base // 8
+        sizeof (unsigned int) * 1,          // xStride// 9
+        sizeof (unsigned int) * width));    // yStride// 10
 
     for (int i = 0; i < channelCount; i++)
     {
@@ -125,10 +126,11 @@ generateRandomFile (
             str, // name // 6
             DeepSlice (
                 type, // type // 7
-                (char*) (&data[i][0][0] - dataWindow.min.x - dataWindow.min.y * width), // base // 8
-                pointerSize * 1,     // xStride// 9
-                pointerSize * width, // yStride// 10
-                sampleSize));        // sampleStride
+                (char*) (&data[i][0][0] - dataWindow.min.x -
+                         dataWindow.min.y * width), // base // 8
+                pointerSize * 1,                    // xStride// 9
+                pointerSize * width,                // yStride// 10
+                sampleSize));                       // sampleStride
     }
 
     file.setFrameBuffer (frameBuffer);
@@ -171,9 +173,10 @@ generateRandomFile (
         for (int j = 0; j < width; j++)
             for (int k = 0; k < channelCount; k++)
             {
-                if (channelTypes[k] == 0) delete[](unsigned int*) data[k][i][j];
-                if (channelTypes[k] == 1) delete[](half*) data[k][i][j];
-                if (channelTypes[k] == 2) delete[](float*) data[k][i][j];
+                if (channelTypes[k] == 0)
+                    delete[] (unsigned int*) data[k][i][j];
+                if (channelTypes[k] == 1) delete[] (half*) data[k][i][j];
+                if (channelTypes[k] == 2) delete[] (float*) data[k][i][j];
             }
 }
 
@@ -221,9 +224,10 @@ readFile (const std::string& copy_filename, int channelCount)
 
     frameBuffer.insertSampleCountSlice (Slice (
         IMF::UINT, // type // 7
-        (char*) (&localSampleCount[0][0] - dataWindow.min.x - dataWindow.min.y * width), // base // 8)
-        sizeof (unsigned int) * 1,       // xStride// 9
-        sizeof (unsigned int) * width)); // yStride// 10
+        (char*) (&localSampleCount[0][0] - dataWindow.min.x -
+                 dataWindow.min.y * width), // base // 8)
+        sizeof (unsigned int) * 1,          // xStride// 9
+        sizeof (unsigned int) * width));    // yStride// 10
 
     for (int i = 0; i < channelCount; i++)
     {
@@ -247,10 +251,11 @@ readFile (const std::string& copy_filename, int channelCount)
             str, // name // 6
             DeepSlice (
                 type, // type // 7
-                (char*) (&data[i][0][0] - dataWindow.min.x - dataWindow.min.y * width), // base // 8)
-                pointerSize * 1,     // xStride// 9
-                pointerSize * width, // yStride// 10
-                sampleSize));        // sampleStride
+                (char*) (&data[i][0][0] - dataWindow.min.x -
+                         dataWindow.min.y * width), // base // 8)
+                pointerSize * 1,                    // xStride// 9
+                pointerSize * width,                // yStride// 10
+                sampleSize));                       // sampleStride
     }
 
     file.setFrameBuffer (frameBuffer);
@@ -328,9 +333,10 @@ readFile (const std::string& copy_filename, int channelCount)
         for (int j = 0; j < width; j++)
             for (int k = 0; k < channelCount; k++)
             {
-                if (channelTypes[k] == 0) delete[](unsigned int*) data[k][i][j];
-                if (channelTypes[k] == 1) delete[](half*) data[k][i][j];
-                if (channelTypes[k] == 2) delete[](float*) data[k][i][j];
+                if (channelTypes[k] == 0)
+                    delete[] (unsigned int*) data[k][i][j];
+                if (channelTypes[k] == 1) delete[] (half*) data[k][i][j];
+                if (channelTypes[k] == 2) delete[] (float*) data[k][i][j];
             }
 }
 
